@@ -22,7 +22,7 @@ class ActionManager(object):
 		return CreateProjectAction().start()
 
 	@classmethod
-	def deploy(cls, production=False):
+	def deploy(cls, environType):
 		""" Deploy the current project
 		"""
-		return DeploymentAction().start(production=production)
+		return DeploymentAction().start(environType)
