@@ -35,7 +35,11 @@ class TemplateTool(object):
 		"AWS::EC2::VPCGatewayAttachment",
 		"AWS::EC2::Route",
 		"AWS::IAM::InstanceProfile",
-		"AWS::ApplicationAutoScaling::ScalableTarget"
+		"AWS::ApplicationAutoScaling::ScalableTarget",
+		"AWS::Cognito::UserPool",
+		"AWS::AppSync::ApiKey",
+		"AWS::IAM::ServiceLinkedRole",
+		"AWS::Lambda::EventSourceMapping"
 	]
 
 	@classmethod
